#
# *tmb* series kernels now use kernel.org versioning
#
%define kernelversion	4
%define patchlevel	1
# sublevel is now used for -stable patches
%define sublevel	15
# extstable is for extended stable patches
%define extstable	0

# Package release
%define mgarel		1

# kernel Makefile extraversion is substituted by
# kpatch/kgit wich are either 0 (empty), rc (kpatch), git (kgit)
%define kpatch		0
# kernel.org -gitX patch (only the number after "git")
%define kgit		0

# Patch tarball tag
%define ktag		tmb
# kernel base name (also name of srpm)
%define kname		kernel-%{ktag}

# release defines
%define rpmtag		%{distsuffix}%{mgaver}
%if %kpatch
%if %kgit
%define rpmrel		%mkrel 0.%{kpatch}.%{kgit}.%{mgarel}
%else
%define rpmrel		%mkrel 0.%{kpatch}.%{mgarel}
%endif
%else
%define rpmrel		%mkrel %{mgarel}
%endif

# fakerel and fakever never change, they are used to fool
# rpm/urpmi/smart
%define fakever		1
%define fakerel		%mkrel 1

# version defines
%if %extstable
%define kversion	%{kernelversion}.%{patchlevel}.%{sublevel}.%{extstable}
%else
%define kversion	%{kernelversion}.%{patchlevel}.%{sublevel}
%endif
%define kverrel		%{kversion}-%{rpmrel}

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %kpatch
%if %sublevel
%define tar_ver		%{kernelversion}.%{patchlevel}
%else
%define tar_ver		%{kernelversion}.%(expr %{patchlevel} - 1)
%endif
%define patch_ver	%{kversion}-%{kpatch}-%{ktag}%{mgarel}
%else
%define tar_ver		%{kernelversion}.%{patchlevel}
%define patch_ver	%{kversion}-%{ktag}%{mgarel}
%endif

# Used for not making too long names for rpms or search paths
%if %kpatch
%if %kgit
%define buildrpmrel	0.%{kpatch}.%{kgit}.%{mgarel}%{rpmtag}
%else
%define buildrpmrel	0.%{kpatch}.%{mgarel}%{rpmtag}
%endif
%else
%define buildrpmrel	%{mgarel}%{rpmtag}
%endif
%define buildrel	%{kversion}-%{buildrpmrel}

# having different top level names for packges means that you have to remove them by hard :(
%define top_dir_name	%{kname}-%{_arch}

%define build_dir	${RPM_BUILD_DIR}/%{top_dir_name}
%define src_dir		%{build_dir}/linux-%{tar_ver}

# disable useless debug rpms...
%define _enable_debug_packages	%{nil}
%define debug_package		%{nil}

# Build defines
%define build_doc		0
%define build_source		1
%define build_devel		1
%define build_debug		0

# xz compress modules
%define build_modxz		1

# Build desktop586 (i586 / 4GB)
%ifarch %{ix86}
%define build_desktop586	0
%endif

# Build desktop (i686 / 4GB) / x86_64
%define build_desktop		1

# Build laptop (i686 / 4GB)/ x86_64
%ifarch %{ix86} x86_64
%define build_laptop		0
%endif

# Build realtime (i686 / 4GB)/x86_64
%define build_realtime		0

# Build server (i686 / 64GB)/x86_64
%define build_server		0

# End of user definitions
%{?_without_desktop586: %global build_desktop586 0}
%{?_without_desktop: %global build_desktop 0}
%{?_without_laptop: %global build_laptop 0}
%{?_without_realtime: %global build_realtime 0}
%{?_without_server: %global build_server 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}
%{?_without_devel: %global build_devel 0}
%{?_without_debug: %global build_debug 0}

%{?_with_desktop586: %global build_desktop586 1}
%{?_with_desktop: %global build_desktop 1}
%{?_with_laptop: %global build_laptop 1}
%{?_with_realtime: %global build_realtime 1}
%{?_with_server: %global build_server 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}
%{?_with_devel: %global build_devel 1}
%{?_with_debug: %global build_debug 1}

# For the .nosrc.rpm
%define build_nosrc	0
%{?_with_nosrc: %global build_nosrc 1}

%define kmake %make
# there are places where parallel make don't work
%define smake make

# Parallelize xargs invocations on smp machines
%define kxargs xargs %([ -z "$RPM_BUILD_NCPUS" ] \\\
	&& RPM_BUILD_NCPUS="`/usr/bin/getconf _NPROCESSORS_ONLN`"; \\\
	[ "$RPM_BUILD_NCPUS" -gt 1 ] && echo "-P $RPM_BUILD_NCPUS")

#
# SRC RPM description
#
Summary: 	Linux kernel built for %vendor with modifications by %{ktag}
Name:		%{kname}
Version: 	%{kversion}
Release: 	%{rpmrel}
License: 	GPLv2
Group: 	 	System/Kernel and hardware
ExclusiveArch: 	%{ix86} x86_64
ExclusiveOS: 	Linux
URL: 		http://www.kernel.org

####################################################################
#
# Sources
#
### This is for full SRC RPM
Source0: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.xz
Source1: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.sign
### This is for stripped SRC RPM
%if %build_nosrc
NoSource: 0
%endif
# This is for disabling mrproper in -devel rpms
Source2: 	disable-mrproper-prepare-scripts-configs-in-devel-rpms.patch

Source4: 	README.kernel-%{ktag}-sources

Source100: 	linux-%{patch_ver}.tar.xz
Source101: 	linux-%{patch_ver}.tar.xz.asc
Source102: 	%{kname}.patchlist

####################################################################
#
# Patches

#
# Patch0 to Patch100 are for core kernel upgrades.
#

# Pre linus patch: ftp://ftp.kernel.org/pub/linux/kernel/v3.0/testing

%if %kpatch
%if %sublevel
Patch2:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/stable-review/patch-%{kversion}-%{kpatch}.xz
Source11:	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/stable-review/patch-%{kversion}-%{kpatch}.sign
%else
Patch1:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/testing/patch-%{kernelversion}.%{patchlevel}-%{kpatch}.xz
Source10:	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/testing/patch-%{kernelversion}.%{patchlevel}-%{kpatch}.sign
%endif
%endif
%if %kgit
Patch2:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/snapshots/patch-%{kernelversion}.%{patchlevel}-%{kpatch}-git%{kgit}.xz
Source11:	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/snapshots/patch-%{kernelversion}.%{patchlevel}-%{kpatch}-git%{kgit}.sign
%endif
%if %sublevel
%if %kpatch
%define prev_sublevel %(expr %{sublevel} - 1)
%if %prev_sublevel
Patch1:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kernelversion}.%{patchlevel}.%{prev_sublevel}.xz
Source10:	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kernelversion}.%{patchlevel}.%{prev_sublevel}.sign
%endif
%else
Patch1:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kernelversion}.%{patchlevel}.%{sublevel}.xz
Source10:	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kernelversion}.%{patchlevel}.%{sublevel}.sign
%endif
%endif
%if %extstable
Patch3:		patch-%{kernelversion}.%{patchlevel}.%{sublevel}.%{extstable}.patch
%endif

#END
####################################################################

# Defines for the things that are needed for all the kernels
#
%define common_description_kernel The kernel package contains the Linux kernel (vmlinuz), the core of your \
%vendor Linux operating system.  The kernel handles the basic functions \
of the operating system:  memory allocation, process allocation, device \
input and output, etc.

### Global Requires/Provides
%define requires1       bootloader-utils >= 1.16-1
%define requires2       dracut >= 038-19
%define requires3       kmod >= 15-2.3
%define requires4       sysfsutils >= 2.1.0-16
%define requires5       kernel-firmware >= 20150722-1

%define kprovides1      %{kname} = %{kverrel}
%define kprovides2      kernel = %{tar_ver}
%define kprovides3      alsa = 1.0.26
%define kprovides_server drbd-api = 88
# conflict dkms packages that dont support kernel-4.1
%define kconflicts1     dkms-broadcom-wl < 6.30.223.248-2.1
%define kconflicts2     dkms-fglrx < 15.200.1046-1.1
%define kconflicts3     dkms-nvidia-current < 346.72-1
%define kconflicts4     dkms-nvidia340 < 340.76-2
%define kconflicts5     dkms-nvidia304 < 304.125-5
%define kconflicts6     dkms-virtualbox < 4.3.28-1
%define kconflicts7     dkms-xtables-addons < 2.7-1
# not supported by x11-server-1.16
%define kconflicts8     dkms-nvidia173 <= 173.14.39
# (tmb) nvidia96xx does not support this kernel or x11-server-1.13
%define kconflicts9     dkms-nvidia96xx <= 96.43.23
# (tmb) conflict too old lvm2 rules to make upgrades work (tv, mga #9536)
%define kconflicts10    lvm2 < 2.02.98-3
# (tmb) conflict too old drakxtools-backend to avoid bogus root=/dev/ (#9536)
%define kconflicts11    drakxtools-backend < 15.37-1
# (tmb) conflict older btrfs-progs to get the new in same transaction and in initrd
%define kconflicts12    btrfs-progs < 4.1.2-1
# (tmb) conflict too old plymouth (#10128)
%define kconflicts13    plymouth < 0.8.6.1-13
# (tmb) conflict too old radeon-firmware to get the uvd firmwares in initrd
%define kconflicts14    radeon-firmware < 20150722-1
# (tmb) conflict older nonfree firmware to get updated ones in initrd
%define kconflicts15    kernel-firmware-nonfree < 20150722-1
# (tmb) conflict old theme to get mga5 theme in initrd
%define kconflicts16    mageia-gfxboot-theme < 4.5.6.6-1
# (tmb) conflict too old grub2(-efi)
%define kconflicts17    grub2 < 2.02-0.git9752.18
%define kconflicts18    grub2-efi < 2.02-0.git9752.18
# (tmb) conflict too old efibootmgr
%define kconflicts19    efibootmgr < 0.11.0-7
# (tmb) conflict for vmmouse breakage (mga#16954)
%define kconflicts20    x11-driver-input-vmmouse < 13.1.0-1

Autoreqprov: 		no
BuildRequires: 		gcc >= 4.8.2-3.1 kmod >= 15-2.3 bc
# for unversioned kmod provides (mga#14235)
BuildRequires:		rpm-mageia-setup-build >= 1.197-1.1

%description
%common_description_kernel


# mkflavour() name flavour processor
# name: the flavour name in the package name
# flavour: first parameter of CreateKernel()
%define mkflavour()					\
%package -n %{kname}-%{1}-%{buildrel}			\
Version:	%{fakever}				\
Release:	%{fakerel}				\
Summary:	%{expand:%{summary_%(echo %{1})}}	\
Group:		System/Kernel and hardware		\
Provides:       %{kname}-%{1}                           \
Provides:       %kprovides1 %kprovides2 %kprovides3     \
%{expand:%%{?kprovides_%{1}:Provides: %{kprovides_%{1}}}} \
Provides:       should-restart = system                 \
Requires(pre):  %requires1 %requires2 %requires3 %requires4 \
Requires:       %requires2 %requires5                   \
Conflicts:      %kconflicts1 %kconflicts2 %kconflicts3  \
Conflicts:      %kconflicts4 %kconflicts5 %kconflicts6  \
Conflicts:      %kconflicts7 %kconflicts8 %kconflicts9  \
Conflicts:      %kconflicts10 %kconflicts11 %kconflicts12 \
Conflicts:      %kconflicts13 %kconflicts14 %kconflicts15 \
Conflicts:      %kconflicts16 %kconflicts17 %kconflicts18 \
Conflicts:      %kconflicts19 %kconflicts20		\
Recommends:     crda iw cpupower                        \
Recommends:     %{kname}-%{1}-latest                    \
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
%description -n %{kname}-%{1}-%{buildrel}		\
%common_description_kernel %{expand:%{info_%(echo %{1})}} \
							\
%if %build_devel					\
%package -n	%{kname}-%{1}-devel-%{buildrel}		\
Version:	%{fakever}				\
Release:	%{fakerel}				\
Summary:	The kernel-devel files for %{kname}-%{1}-%{buildrel} \
Group:		Development/Kernel			\
Requires:	glibc-devel ncurses-devel make gcc perl	\
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
Provides:	kernel-devel = %{kverrel} 		\
Recommends:     %{kname}-%{1}-devel-latest              \
%description -n %{kname}-%{1}-devel-%{buildrel}		\
This package contains the kernel-devel files that should be enough to build \
3rdparty drivers against for use with %{kname}-%{1}-%{buildrel}. \
							\
If you want to build your own kernel, you need to install the full \
%{kname}-source-%{buildrel} rpm.			\
%endif							\
							\
%package -n %{kname}-%{1}-latest			\
Version:	%{kversion}				\
Release:	%{rpmrel}				\
Summary:	Virtual rpm for latest %{kname}-%{1}	\
Group:		System/Kernel and hardware		\
Requires:	%{kname}-%{1}-%{buildrel}		\
Obsoletes:	%{kname}-%{1}-smp-latest <= 2.6.22-0.rc5.%{expand:%mkrel 1} \
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
%description -n %{kname}-%{1}-latest			\
This package is a virtual rpm that aims to make sure you always have the \
latest %{kname}-%{1} installed...			\
							\
%if %build_devel					\
%package -n %{kname}-%{1}-devel-latest			\
Version:	%{kversion}				\
Release:	%{rpmrel}				\
Summary:	Virtual rpm for latest %{kname}-%{1}-devel \
Group:		Development/Kernel			\
Requires:	%{kname}-%{1}-devel-%{buildrel}		\
Obsoletes:	%{kname}-%{1}-smp-devel-latest <= 2.6.22-0.rc5.%{expand:%mkrel 1} \
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
%description -n %{kname}-%{1}-devel-latest		\
This package is a virtual rpm that aims to make sure you always have the \
latest %{kname}-%{1}-devel installed...			\
%endif							\
							\
%post -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-post \
%posttrans -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-posttrans \
%preun -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-preun \
%postun -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-postun \
							\
%if %build_devel					\
%post -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1}-post \
%preun -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1}-preun \
%endif							\
							\
%files -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1} \
%files -n %{kname}-%{1}-latest				\
							\
%if %build_devel					\
%files -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1} \
%files -n %{kname}-%{1}-devel-latest			\
%endif


#
# kernel-desktop586: i586, smp-alternatives, 4GB
#
%ifarch %{ix86}
%if %build_desktop586
%define summary_desktop586 Linux kernel for desktop use with i586 and up to 4GB RAM
%define info_desktop586 This kernel is compiled for desktop use, single or \
multiple i586 processor(s)/core(s) and less than 4GB RAM (usually 3-3.5GB \
detected, if you need/want to use all 4GB or more, install %{kname}-server),\
 using full preempt, BFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%mkflavour desktop586
%endif
%endif

#
# kernel-desktop: i686, smp-alternatives, 4 GB / x86_64
#
%if %build_desktop
%ifarch %{ix86}
%define summary_desktop Linux Kernel for desktop use with i686 and up to 4GB RAM
%define info_desktop This kernel is compiled for desktop use, single or \
multiple i686 processor(s)/core(s) and less than 4GB RAM (usually 3-3.5GB \
detected, if you need/want to use all 4GB or more, install %{kname}-server), \
using full preempt, BFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%else
%define summary_desktop Linux Kernel for desktop use with %{_arch}
%define info_desktop This kernel is compiled for desktop use, single or \
multiple %{_arch} processor(s)/core(s), using full preempt, BFS cpu \
scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%endif
%mkflavour desktop
%endif

#
# kernel-laptop: i686, smp-alternatives, 4GB / x86_64
#
%if %build_laptop
%ifarch %{ix86}
%define summary_laptop Linux kernel for laptop use with i686 and up to 4GB
%define info_laptop This kernel is compiled for laptop use, single or \
multiple i686 processor(s)/core(s) and less than 4GB RAM (usually 3-3.5GB \
detected, if you need/want to use all 4GB or more, install %{kname}-server), \
using HZ_250 to save battery, voluntary preempt, BFS cpu scheduler, \
cfq i/o scheduler and some other laptop-specific optimizations. \
If you want to sacrifice battery life for performance, you better use the \
%{kname}-desktop. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter. \
NOTE! This kernel also uses TuxOnIce by default.
%else
%define summary_laptop Linux kernel for laptop use with %{_arch}
%define info_laptop This kernel is compiled for laptop use, single or \
multiple %{_arch} processor(s)/core(s), using HZ_250 to save battery, \
voluntary preempt, BFS cpu scheduler, cfq i/o scheduler and some other \
laptop-specific optimizations. If you want to sacrifice battery life for \
performance, you better use the %{kname}-desktop. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter. \
NOTE! This kernel also uses TuxOnIce by default.
%endif
%mkflavour laptop
%endif

%if %build_realtime
%ifarch %{ix86}
%define summary_realtime Linux Kernel for desktop use with i686 & 4GB RAM
%define info_realtime This kernel is compiled for desktop use, single or \
multiple i686 processor(s)/core(s) and less than 4GB RAM, using full \
preempt and realtime, BFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%else
%define summary_realtime Linux Kernel for desktop use with %{_arch}
%define info_realtime This kernel is compiled for desktop use, single or \
multiple %{_arch} processor(s)/core(s), using full preempt and realtime, \
BFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%endif
%mkflavour realtime
%endif

#
# kernel-server: i686, smp-alternatives, 64 GB /x86_64
#
%if %build_server
%ifarch %{ix86}
%define summary_server Linux Kernel for server use with i686 & 64GB RAM
%define info_server This kernel is compiled for server use, single or \
multiple i686 processor(s)/core(s) and up to 64GB RAM using PAE, using \
no preempt, BFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%else
%define summary_server Linux Kernel for server use with %{_arch}
%define info_server This kernel is compiled for server use, single or \
multiple %{_arch} processor(s)/core(s), using no preempt, BFS cpu scheduler \
and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%endif
%mkflavour server
%endif

#
# kernel-source
#
%if %build_source
%package -n %{kname}-source-%{buildrel}
Version: 	%{fakever}
Release: 	%{fakerel}
Requires: 	glibc-devel, ncurses-devel, make, gcc, perl, diffutils
Summary: 	The Linux source code for %{kname}-%{buildrel}
Group: 		Development/Kernel
Autoreqprov: 	no
Provides: 	kernel-source = %{kverrel}
Buildarch:	noarch

%description -n %{kname}-source-%{buildrel}
The %{kname}-source package contains the source code files for the %{ktag}
series Linux kernel. Theese source files are only needed if you want to
build your own custom kernel that is better tuned to your particular hardware.

If you only want the files needed to build 3rdparty (nVidia, Ati, dkms-*,...)
drivers against, install the *-devel-* rpm that is matching your kernel.


%post -n %{kname}-source-%{buildrel}
for i in /lib/modules/%{kversion}-%{ktag}-*-%{buildrpmrel}; do
        if [ -d $i ]; then
		if [ ! -L $i/build -a ! -L $i/source ]; then
            		ln -sf /usr/src/%{kversion}-%{ktag}-%{buildrpmrel} $i/build
            		ln -sf /usr/src/%{kversion}-%{ktag}-%{buildrpmrel} $i/source
		fi
        fi
done

%preun -n %{kname}-source-%{buildrel}
for i in /lib/modules/%{kversion}-%{ktag}-*-%{buildrpmrel}/{build,source}; do
	if [ -L $i ]; then
		if [ "$(readlink $i)" = "/usr/src/%{kversion}-%{ktag}-%{buildrpmrel}" ]; then
			rm -f $i
		fi
	fi
done
exit 0

#
# kernel-source-latest: virtual rpm
#
%package -n %{kname}-source-latest
Version: 	%{kversion}
Release: 	%{rpmrel}
Summary: 	Virtual rpm for latest %{kname}-source
Group:   	Development/Kernel
Requires: 	%{kname}-source-%{buildrel}
Buildarch:	noarch

%description -n %{kname}-source-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname}-source installed...
%endif

#
# kernel-doc: documentation for the Linux kernel
#
%if %build_doc
%package -n %{kname}-doc
Version: 	%{kversion}
Release: 	%{rpmrel}
Summary: 	Various documentation bits found in the %{kname} source
Group: 		Documentation
Buildarch:	noarch

%description -n %{kname}-doc
This package contains documentation files from the %{kname} source.
Various bits of information about the Linux kernel and the device drivers
shipped with it are documented in these files. You also might want install
this package if you need a reference to the options that can be passed to
Linux kernel modules at load time.
%endif

#
# End packages - here begins build stage
#
%prep
%setup -q -n %top_dir_name -c

%setup -q -n %top_dir_name -D -T -a100

%define patches_dir ../%{patch_ver}/

cd %src_dir

%if %sublevel
%if %kpatch
%if %prev_sublevel
%patch1 -p1
%endif
%patch2 -p1
%else
%patch1 -p1
%endif
%else
%if %kpatch
%patch1 -p1
%endif
%endif
%if %kgit
%patch2 -p1
%endif
%if %extstable
%patch3 -p1
%endif

%{patches_dir}/scripts/apply_patches


# PATCH END

#
# Setup Begin
#

# Prepare all the variables for calling create_configs
%if %build_debug
%define debug --debug
%else
%define debug --no-debug
%endif

%{patches_dir}/scripts/create_configs %debug --user_cpu="%{_arch}"

# make sure the kernel has the sublevel we know it has...
LC_ALL=C perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name '*~' -o -name '*.orig' -o -name '*.append' |%kxargs rm -f


%build
# Common target directories
%define _kerneldir /usr/src/%{kversion}-%{ktag}-%{buildrpmrel}
%define _bootdir /boot
%define _modulesdir /lib/modules

# Directories definition needed for building
%define temp_root %{build_dir}/temp-root
%define temp_source %{temp_root}%{_kerneldir}
%define temp_boot %{temp_root}%{_bootdir}
%define temp_modules %{temp_root}%{_modulesdir}


PrepareKernel() {
	name=$1
	extension=$2
	echo "Make dep for kernel $extension"
	%smake -s mrproper

	if [ -z "$name" ]; then
		cp arch/x86/configs/%{_arch}_defconfig-desktop .config
	else
		cp arch/x86/configs/%{_arch}_defconfig-$name .config
	fi

	# make sure EXTRAVERSION says what we want it to say
	%if %extstable
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = .%{extstable}-$extension/" Makefile
	%else
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -$extension/" Makefile
	%endif

	%smake oldconfig
}


BuildKernel() {
	KernelVer=$1
	echo "Building kernel $KernelVer"

	%kmake -s all

	# Start installing stuff
	install -d %{temp_boot}
	install -m 644 System.map %{temp_boot}/System.map-$KernelVer
	install -m 644 .config %{temp_boot}/config-$KernelVer

	cp -f arch/%{_arch}/boot/bzImage %{temp_boot}/vmlinuz-$KernelVer

	# modules
	install -d %{temp_modules}/$KernelVer
	%smake INSTALL_MOD_PATH=%{temp_root} KERNELRELEASE=$KernelVer modules_install

	# remove /lib/firmware, we use a separate kernel-firmware
	rm -rf %{temp_root}/lib/firmware
}


SaveDevel() {
	devel_flavour=$1

	DevelRoot=/usr/src/%{kversion}-%{ktag}-$devel_flavour-%{buildrpmrel}
	TempDevelRoot=%{temp_root}$DevelRoot

	mkdir -p $TempDevelRoot
	for i in $(find . -name 'Makefile*'); do cp -R --parents $i $TempDevelRoot;done
	for i in $(find . -name 'Kconfig*' -o -name 'Kbuild*' -o -name config.mk); do cp -R --parents $i $TempDevelRoot;done
	cp -fR include $TempDevelRoot
	cp -fR scripts $TempDevelRoot
	%ifarch %{ix86} x86_64
		cp -fR arch/x86/kernel/asm-offsets.{c,s} $TempDevelRoot/arch/x86/kernel/
		cp -fR arch/x86/kernel/asm-offsets_{32,64}.c $TempDevelRoot/arch/x86/kernel/
		cp -fR arch/x86/syscalls/syscall* $TempDevelRoot/arch/x86/syscalls/
		cp -fR arch/x86/include $TempDevelRoot/arch/x86/
		cp -fR arch/x86/tools $TempDevelRoot/arch/x86/
	%else
		cp -fR arch/%{_arch}/kernel/asm-offsets.{c,s} $TempDevelRoot/arch/%{_arch}/kernel/
		cp -fR arch/%{_arch}/include $TempDevelRoot/arch/%{_arch}/
	%endif
	cp -fR kernel/bounds.c $TempDevelRoot/kernel/
	cp -fR tools/include $TempDevelRoot/tools/
	cp -fR .config Module.symvers $TempDevelRoot
	cp -fR 3rdparty/mkbuild.pl $TempDevelRoot/3rdparty/

	# Needed for truecrypt build (Danny)
	cp -fR drivers/md/dm.h $TempDevelRoot/drivers/md/

	# Needed for lguest
	cp -fR drivers/lguest/lg.h $TempDevelRoot/drivers/lguest/

	# Needed for lirc_gpio (Anssi Hannula, #39004, #54907)
	cp -fR drivers/media/pci/bt8xx/bttv{,p}.h $TempDevelRoot/drivers/media/pci/bt8xx/
	cp -fR drivers/media/pci/bt8xx/bt848.h $TempDevelRoot/drivers/media/pci/bt8xx/
	cp -fR drivers/media/common/btcx-risc.h $TempDevelRoot/drivers/media/common/

	# Needed for external dvb tree (#41418)
	cp -fR drivers/media/dvb-core/*.h $TempDevelRoot/drivers/media/dvb-core/
	cp -fR drivers/media/dvb-frontends/lgdt330x.h $TempDevelRoot/drivers/media/dvb-frontends/

	# add acpica header files, needed for fglrx build
	cp -fR drivers/acpi/acpica/*.h $TempDevelRoot/drivers/acpi/acpica/

	for i in alpha arc arm arm26 arm64 avr32 blackfin c6x cris frv h8300 hexagon ia64 \
		 microblaze mips m32r m68k m68knommu metag mn10300 nios2 openrisc parisc \
		 powerpc ppc s390 sh sh64 score sparc tile unicore32 v850 xtensa; do
		rm -rf $TempDevelRoot/arch/$i
	done

	%ifnarch %{ix86} x86_64
		rm -rf $TempDevelRoot/arch/x86
	%endif

	rm -rf $TempDevelRoot/include/kvm/arm*
	rm -rf $TempDevelRoot/include/soc/tegra

	# Clean the scripts tree, and make sure everything is ok (sanity check)
	# running prepare+scripts (tree was already "prepared" in build)
	pushd $TempDevelRoot >/dev/null
		%smake -s prepare scripts clean
	popd >/dev/null

	rm -f $TempDevelRoot/.config.old

	# fix permissions
	chmod -R a+rX $TempDevelRoot

	# disable mrproper in -devel rpms
	patch -p1 -d $TempDevelRoot -i %{SOURCE2}

	kernel_devel_files=../kernel_devel_files.$devel_flavour


### Create the kernel_devel_files.*
cat > $kernel_devel_files <<EOF
%dir $DevelRoot
%dir $DevelRoot/arch
%dir $DevelRoot/include
$DevelRoot/3rdparty
$DevelRoot/Documentation
$DevelRoot/arch/Kconfig
$DevelRoot/arch/um
%ifarch %{ix86} x86_64
$DevelRoot/arch/x86
%endif
$DevelRoot/block
$DevelRoot/crypto
$DevelRoot/drivers
$DevelRoot/firmware
$DevelRoot/fs
$DevelRoot/include/Kbuild
$DevelRoot/include/acpi
$DevelRoot/include/asm-generic
$DevelRoot/include/clocksource
$DevelRoot/include/config
$DevelRoot/include/crypto
$DevelRoot/include/drm
$DevelRoot/include/dt-bindings
$DevelRoot/include/generated
$DevelRoot/include/keys
$DevelRoot/include/kvm
$DevelRoot/include/linux
$DevelRoot/include/math-emu
$DevelRoot/include/media
$DevelRoot/include/memory
$DevelRoot/include/misc
$DevelRoot/include/net
$DevelRoot/include/pcmcia
$DevelRoot/include/ras
$DevelRoot/include/rdma
$DevelRoot/include/rxrpc
$DevelRoot/include/scsi
$DevelRoot/include/soc
$DevelRoot/include/sound
$DevelRoot/include/target
$DevelRoot/include/trace
$DevelRoot/include/uapi
$DevelRoot/include/video
$DevelRoot/include/xen
$DevelRoot/init
$DevelRoot/ipc
$DevelRoot/kernel
$DevelRoot/lib
$DevelRoot/mm
$DevelRoot/net
$DevelRoot/samples
$DevelRoot/scripts
$DevelRoot/security
$DevelRoot/sound
$DevelRoot/tools
$DevelRoot/usr
$DevelRoot/virt
$DevelRoot/.config
$DevelRoot/Kbuild
$DevelRoot/Kconfig
$DevelRoot/Makefile
$DevelRoot/Module.symvers
%doc README.kernel-%{ktag}-sources
EOF


### Create -devel Post script on the fly
cat > $kernel_devel_files-post <<EOF
if [ -d /lib/modules/%{kversion}-%{ktag}-$devel_flavour-%{buildrpmrel} ]; then
	rm -f /lib/modules/%{kversion}-%{ktag}-$devel_flavour-%{buildrpmrel}/{build,source}
	ln -sf $DevelRoot /lib/modules/%{kversion}-%{ktag}-$devel_flavour-%{buildrpmrel}/build
	ln -sf $DevelRoot /lib/modules/%{kversion}-%{ktag}-$devel_flavour-%{buildrpmrel}/source
fi
EOF


### Create -devel Preun script on the fly
cat > $kernel_devel_files-preun <<EOF
if [ -L /lib/modules/%{kversion}-%{ktag}-$devel_flavour-%{buildrpmrel}/build ]; then
	rm -f /lib/modules/%{kversion}-%{ktag}-$devel_flavour-%{buildrpmrel}/build
fi
if [ -L /lib/modules/%{kversion}-%{ktag}-$devel_flavour-%{buildrpmrel}$devel_cpu/source ]; then
	rm -f /lib/modules/%{kversion}-%{ktag}-$devel_flavour-%{buildrpmrel}/source
fi
exit 0
EOF
}


CreateFiles() {
	kernel_flavour=$1

	kernel_files=../kernel_files.$kernel_flavour


### Create the kernel_files.*
cat > $kernel_files <<EOF
%{_bootdir}/System.map-%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}
%{_bootdir}/config-%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}
%{_bootdir}/vmlinuz-%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}
%dir %{_modulesdir}/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/
%{_modulesdir}/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/kernel
%{_modulesdir}/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/modules.*
%doc README.kernel-%{ktag}-sources
EOF


### Create kernel Post script
cat > $kernel_files-post <<EOF
/sbin/installkernel -L %{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}
pushd /boot > /dev/null
if [ -L vmlinuz-%{ktag}-$kernel_flavour ]; then
	rm -f vmlinuz-%{ktag}-$kernel_flavour
fi
ln -sf vmlinuz-%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel} vmlinuz-%{ktag}-$kernel_flavour
if [ -L initrd-%{ktag}-$kernel_flavour.img ]; then
	rm -f initrd-%{ktag}-$kernel_flavour.img
fi
ln -sf initrd-%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}.img initrd-%{ktag}-$kernel_flavour.img
popd > /dev/null
%if %build_devel
# create kernel-devel symlinks if matching -devel- rpm is installed
if [ -d /usr/src/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel} ]; then
	rm -f /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/{build,source}
	ln -sf /usr/src/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel} /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/build
	ln -sf /usr/src/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel} /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/source
fi
%endif
%if %build_source
# create kernel-source symlinks only if matching -devel- rpm is not installed
if [ -d /usr/src/%{kversion}-%{ktag}-%{buildrpmrel} -a ! -d /usr/src/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel} ]; then
	rm -f /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/{build,source}
	ln -sf /usr/src/%{kversion}-%{ktag}-%{buildrpmrel} /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/build
	ln -sf /usr/src/%{kversion}-%{ktag}-%{buildrpmrel} /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/source
fi
%endif
EOF

### Create kernel Posttran script
cat > $kernel_files-posttrans <<EOF
if [ -x /usr/sbin/dkms_autoinstaller -a -d /usr/src/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel} ]; then
    /usr/sbin/dkms_autoinstaller start %{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}
fi
EOF

### Create kernel Preun script on the fly
cat > $kernel_files-preun <<EOF
/sbin/installkernel -R %{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}
pushd /boot > /dev/null
if [ -L vmlinuz-%{ktag}-$kernel_flavour ]; then
	if [ "$(readlink vmlinuz-%{ktag}-$kernel_flavour)" = "vmlinuz-%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}" ]; then
		rm -f vmlinuz-%{ktag}-$kernel_flavour
	fi
fi
if [ -L initrd-%{ktag}-$kernel_flavour.img ]; then
	if [ "$(readlink initrd-%{ktag}-$kernel_flavour.img)" = "initrd-%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}.img" ]; then
		rm -f initrd-%{ktag}-$kernel_flavour.img
	fi
fi
popd > /dev/null
%if %build_devel
if [ -L /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/build ]; then
	rm -f /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/build
fi
if [ -L /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/source ]; then
	rm -f /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}/source
fi
%endif
exit 0
EOF


### Create kernel Postun script on the fly
cat > $kernel_files-postun <<EOF
/sbin/kernel_remove_initrd %{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel}
rm -rf /lib/modules/%{kversion}-%{ktag}-$kernel_flavour-%{buildrpmrel} > /dev/null
EOF
}


CreateKernel() {
	flavour=$1

	PrepareKernel $flavour %{ktag}-$flavour-%{buildrpmrel}

	BuildKernel %{kversion}-%{ktag}-$flavour-%{buildrpmrel}
	%if %build_devel
		SaveDevel $flavour
	%endif
	CreateFiles $flavour
}


###
# DO it...
###


# Create a simulacro of buildroot
rm -rf %{temp_root}
install -d %{temp_root}


#make sure we are in the directory
cd %src_dir

%ifarch %{ix86}
%if %build_desktop586
CreateKernel desktop586
%endif
%endif

%if %build_desktop
CreateKernel desktop
%endif

%if %build_laptop
CreateKernel laptop
%endif

%if %build_realtime
CreateKernel realtime
%endif

%if %build_server
CreateKernel server
%endif


# kernel-source is shipped as a clean source tree, with no preparation
%if %build_source
    PrepareKernel "" %{buildrpmrel}%{ktag}custom
%smake -s mrproper
%endif


###
### install
###
%install
install -m 644 %{SOURCE4}  .

cd %src_dir

# Directories definition needed for installing
%define target_source %{buildroot}%{_kerneldir}
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}

# We want to be able to test several times the install part
rm -rf %{buildroot}
cp -a %{temp_root} %{buildroot}

# Create directories infastructure
%if %build_source
install -d %{target_source}

tar cf - . | tar xf - -C %{target_source}
chmod -R a+rX %{target_source}

# we remove all the source files that we don't ship
# first architecture files
for i in alpha arc arm arm26 arm64 avr32 blackfin c6x cris frv h8300 hexagon ia64 \
	 microblaze mips m32r m68k m68knommu metag mn10300 nios2 openrisc parisc \
	 powerpc ppc s390 sh sh64 score sparc tile v850 xtensa unicore32; do
	rm -rf %{target_source}/arch/$i
done

%ifnarch %{ix86} x86_64
	rm -rf %{target_source}/arch/x86
%endif

rm -rf %{target_source}/include/kvm/arm*

# other misc files
rm -f %{target_source}/{.config.old,.config.cmd,.mailmap,.missing-syscalls.d,arch/.gitignore}
rm -rf %{target_source}/.tmp_depmod/

#endif %build_source
%endif

# compressing modules
%if %{build_modxz}
find %{target_modules} -name "*.ko" | %kxargs xz -6e
%else
find %{target_modules} -name "*.ko" | %kxargs gzip -9
%endif

# We used to have a copy of PrepareKernel here
# Now, we make sure that the thing in the linux dir is what we want it to be
for i in %{target_modules}/*; do
        rm -f $i/build $i/source
done

# sniff, if we compressed all the modules, we change the stamp :(
# we really need the depmod -ae here
pushd %{target_modules}
for i in *; do
        /sbin/depmod -ae -b %{buildroot} -F %{target_boot}/System.map-$i $i
        echo $?
done

# create modules.description
for i in *; do
        pushd $i
        echo "Creating modules.description for $i"
        modules=`find . -name "*.ko.[g,x]z"`
        echo $modules | %kxargs /sbin/modinfo \
        | perl -lne 'print "$name\t$1" if $name && /^description:\s*(.*)/; $name = $1 if m!^filename:\s*(.*)\.k?o!; $name =~ s!.*/!!' > modules.description
        popd
done
popd


# We don't want to remove this, the whole reason of its existence is to be
# able to do several rpm --short-circuit -bi for testing install
# phase without repeating compilation phase
#rm -rf %{temp_root}

###
### source and doc file lists
###
%if %build_source
%files -n %{kname}-source-%{buildrel}
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/3rdparty
%{_kerneldir}/Documentation
%{_kerneldir}/arch/Kconfig
%{_kerneldir}/arch/um
%ifarch %{ix86} x86_64
%{_kerneldir}/arch/x86
%endif
%{_kerneldir}/block
%{_kerneldir}/crypto
%{_kerneldir}/drivers
%{_kerneldir}/firmware
%{_kerneldir}/fs
%{_kerneldir}/include/Kbuild
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm-generic
%{_kerneldir}/include/clocksource
%{_kerneldir}/include/crypto
%{_kerneldir}/include/drm
%{_kerneldir}/include/dt-bindings
%{_kerneldir}/include/keys
%{_kerneldir}/include/kvm
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/media
%{_kerneldir}/include/memory
%{_kerneldir}/include/misc
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/ras
%{_kerneldir}/include/rdma
%{_kerneldir}/include/rxrpc
%{_kerneldir}/include/scsi
%{_kerneldir}/include/soc
%{_kerneldir}/include/sound
%{_kerneldir}/include/target
%{_kerneldir}/include/trace
%{_kerneldir}/include/uapi
%{_kerneldir}/include/video
%{_kerneldir}/include/xen
%{_kerneldir}/init
%{_kerneldir}/ipc
%{_kerneldir}/kernel
%{_kerneldir}/lib
%{_kerneldir}/mm
%{_kerneldir}/net
%{_kerneldir}/samples
%{_kerneldir}/scripts
%{_kerneldir}/security
%{_kerneldir}/sound
%{_kerneldir}/tools
%{_kerneldir}/usr
%{_kerneldir}/virt
%{_kerneldir}/.gitignore
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Kbuild
%{_kerneldir}/Kconfig
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%doc README.kernel-%{ktag}-sources

%files -n %{kname}-source-latest
%endif

%if %build_doc
%files -n %{kname}-doc
%doc linux-%{tar_ver}/Documentation/*
%endif



%changelog
* Fri Dec 25 2015 tmb <tmb> 4.1.15-1.mga5
+ Revision: 914623
- update to 4.1.15
- drop merged /obsolete patches:
  * AX10, BM01-BM04, CK02, DG01-DG04, DG07, DG20-DG30, DG40, DI01, DM10, DM11
  * DN10, DN12, DU01-DU02, DV10, FA01, FB01-FB02, FE01, FE10-FE11
- update patches:
  * BB01-BB03: BFQ patchset v7r8-4.1
  * CK01: 4.1-ck2 patchset including BFS 464
  * FR01: reiser4 support
- rebase paches:
  * MB02: 3rdparty merge
- add patches:
  * AA01-AA13: stable queue fixes
  * BS01-BS02: SCSI: Fix NULL pointer dereference in RTPM of block layer
  * CK02: fix BFS scheduler for changes to should_resched() in 4.1.12
  * DA01: ahci: Fix softreset failed issue of Port Multiplier
  * DA02: sata_sil: disable trim
  * DB01: silence DT errors on non-DT 32bit systems (mga#17010)
  * DG01: drm/nouveau/bios/fan: hardcode the fan mode to linear
  * DG02: drm/ttm: Fix a read/write lock imbalance (fixes vmgfx hang)
  * DM10: md: remove check for MD_RECOVERY_NEEDED in action_store (reshape fix)
  * DM20: airspy: increase USB control message buffer size (fw load hang fix)
  * MB14: ndiswrapper buildfix
  * NW01-NW08: QCA6174 fixes (mga#16915)
  * NW20: rtlwifi: rtl8821ae: Fix lockups on boot
  * NX20: xen/events/fifo: Consume unprocessed events when a CPU dies
- add security fixes:
  * AX10: KVM: svm: unconditionally intercept #DB (CVE-2015-8104)
  * DM21: media/vivid-osd: fix info leak in ioctl (CVE-2015-7884)
  * DS10: staging/dgnc: fix info leak in ioctl (CVE-2015-7885)
  * FO01: ovl: fix permission checking for setattr (CVE-2015-8660)
  * NX01-NX07: xen paravirtualized drivers incautious about shared memory contents
               (CVE-2015-8550 / XSA-155)
  * NX11-NX15: xen pciback missing sanity checks leading to crash
               (CVE-2015-8551,CVE-2015-8552 / XSA-157)
  * SK01: KEYS: Don't permit request_key() to construct a new keyring (CVE-2015-7872)
- enable DRM_I915_PRELIMINARY_HW_SUPPORT for Skylake support (mga#17174)
- update conflicts on old dkms and firmware packages
- update defconfigs
- update filelists

* Fri May 22 2015 tmb <tmb> 3.19.8-1.mga5
+ Revision: 822499
- update to 3.19.8
- drop merged patches:
  * AX01-AX02, DG05-DG06, DN01, DN11, DN13, DU03-DU04
- add patches:
  * AX10: x86/spinlocks: Fix regression in spinlock contention detection
  * BM01: blk-mq: fix CPU hotplug handling
  * BM02: blk-mq: fix race between timeout and CPU hotplug
  * BM03: blk-mq: fix FUA request hang
  * BM04: blk-mq: don't lose requests if a stopped queue restarts
  * DG20: drm/radeon: Use drm_calloc_ab for CS relocs
  * DG21: drm/radeon: adjust pll when audio is not enabled
  * DG22: drm/radeon: add SI DPM quirk for Sapphire R9 270 Dual-X 2G GDDR5
  * DG23: drm/radeon: fix lockup when BOs aren't part of the VM on release
  * DG24: drm/radeon: reset BOs address after clearing it.
  * DG25: drm/radeon: check new address before removing old one
  * DG26: drm/radeon: disable semaphores for UVD V1 (v2)
  * DG27: drm/radeon: fix userptr BO unpin bug v3
  * DG28: drm/radeon: make VCE handle check more strict
  * DG29: drm/radeon: make UVD handle checking more strict
  * DG30: drm/radeon: more strictly validate the UVD codec
  * DG40: drm: Zero out invalid vblank timestamp in drm_update_vblank_count
  * DM10: md/raid5: don't record new size if resize_stripes fails.
  * DM11: md/raid0: fix restore to sector variable in
  * DV10: vhost/scsi: potential memory corruption
  * FA01: aio: fix serial draining in exit_aio()
  * FB01: Btrfs: fix BUG_ON in btrfs_orphan_add() when delete unused
  * FB02: btrfs: unlock i_mutex after attempting to delete subvolume during send
  * FE01: efivarfs: Ensure VariableName is NUL-terminated
  * FE10: ext4: fix data corruption caused by unwritten and delayed
  * FE11: ext4: move check under lock scope to close a race.

* Mon Mar 30 2015 tmb <tmb> 3.19.3-1.mga5
+ Revision: 819386
- update to 3.19.3
- update patches:
  * BB01-BB03: BFQ block scheduler
  * CK01: Con Colivas -ck patchset including BFS cpu scheduler
  * FR01: reiser4 support
- only build kernel-tmb-desktop
  * support 64GB RAM even on i586
- add patches:
  * AX01-AX02: restore mwait_idle() support
  * DG01: drm/i915: Make sample_c messages go faster on Haswell
  * DG02: drm/i915: Improve HiZ throughput on Cherryview
  * DG03: drm/i915: Enable the HiZ RAW Stall Optimization on Broadwell
  * DG04: drm/i915: Ensure the HiZ RAW Stall Optimization is on for Cherryview
  * DG05: drm/i915: Align initial plane backing objects correctly
  * DG06: drm/i915: Push vblank enable/disable past encoder->enable/disable
  * DG07: drm/i915: Revert back to legacy turbo for vlv, fixes random crashes
  * DI01: Input: psmouse - support for the FocalTech PS/2 protocol extensions
  * DN01: net/tg3: Hold tp->lock before calling tg3_halt() from tg3_init_one()
  * DN10: net/wireless/ath9k: Update PCI IDs for AR9565
  * DN11: net/wireless/rtlwifi: Improve handling of IPv6 packets
  * DN12: net/wireless/brcmfmac: Add support for bcm43340/1 wireless chipsets
  * DN13: net/wireless/iwlwifi: mvm: BT Coex - fix a NULL pointer exception
  * DS01: alsa: Add VT1613 AC97 codec support
  * DU01: usb/xhci: remove unused parameter 'xhci' in function xhci_handshake()
  * DU02: usb/xhci: clean up work to remove unused parameters for functions in xhci-mem.c
  * DU03: usb/xhci: handle Config Error Change (CEC) in xhci driver
  * DU04: usb/xhci: apply XHCI_AVOID_BEI quirk to all Intel xHCI controllers
  * DV01: video: fbdev: fix possible null dereference
  * FR02: reiser4 buildfixes for kernel 3.19
- update conflicts on old dkms and firmware packages
- update defconfigs
- update filelists

* Sun Jan 18 2015 tmb <tmb> 3.18.3-1.mga5
+ Revision: 811225
- update to 3.18.3
- update patches:
  * BB01-BB03: BFQ I/O sceduler v7r7 for 3.18
  * CK01: -ck patchset including BFS cpu scheduler 0.460
  * FR01: reiser4 support
- drop merged patches
  * CK02: BFS scheduler update
  * DA01-DA02: acpi blacklist updates
  * DM13-DM14: mdadm fixes
  * FN10: fsnotify umount hang fix
  * FO01-FO09: overlay filesystem support
  * NC01-NC02: duplicate symlinks fix
- disable KP01 (TuxOnIce support, currently broken)
- update defconfigs
- update filelists

  + tv <tv>
    - s/uggests:/Recommends:/

* Sat Aug 30 2014 tmb <tmb> 3.14.17-2.mga5
+ Revision: 669675
- add patches:
  * AA01-AA45: stable queue fixes including some CVEs
  * CK02: update bfs scheduler to 454
  * DM10: md/raid6: avoid data corruption during recovery of double-degraded RAID6
  * DM11: md/raid10: fix memory leak when reshaping a RAID10
  * DM12: md/raid10: Fix memory leak when raid10 reshape completes
  * DM13: md/raid10: avoid memory leak on error path during reshape
  * DM14: md/raid10: always initialise ->state on newly allocated r10_bio
  * DN01: revert 'iwlwifi: dvm: don't enable CTS to self' as it is reported to
          cause a big packet loss on some hw

* Fri Aug 29 2014 tmb <tmb> 3.14.17-1.mga5
+ Revision: 669175
- update to 3.14.17
- drop merged patches
- update conflicts on dkms packages supporting 3.14 series kernels
- update defconfigs

* Sun Jun 01 2014 tmb <tmb> 3.14.5-1.mga5
+ Revision: 630333
- update to 3.14.5
- drop merged / obsolete patches:
  * AX10-AX11: restored mwait_idle()
  * AX16: AMD F16h Erratum792
  * DA21: sata_sis pm support
  * DI01-DI03: ALPS updates
  * DN01: asix bugfix
  * FS01-FS02: squashfs multi-decompressor support
- update patches:
  * CK01: -ck1 patchset
  * FO01-FO09: overlayfs support
  * FR01: reiser4 support
  * KP01: TuxOnIce support
- add patches:
  * DM10: md/raid10: call wait_barrier() for each request submitted
  * DN01: iwlwifi: mvm: disable beacon filtering
  * DS10: ALSA: hda - Fix onboard audio on Intel H97/Z97 chipsets
  * FK01: kernfs: add back missing error check in kernfs_fop_mmap()
  * MB13: ndiswrapper buildfix
  * BB01-BB03: BFQ io scheduler support (set as default)
- update defconfigs
- disable AUDITSYSCALL as its broken beyond repair
  (avoids CVE-2014-3917, and other upcoming CVEs)

* Fri May 16 2014 tmb <tmb> 3.12.20-1.mga5
+ Revision: 623031
- update to 3.12.20
- drop merged patch: NI50
- require fixed kmod

* Thu Apr 24 2014 tmb <tmb> 3.12.18-1.mga5
+ Revision: 617596
- update to 3.12.18
- enable Intel P-state driver (mga#13080)
- enable FB_SIMPLE 0n x86_64 too

* Sat Apr 12 2014 tmb <tmb> 3.12.17-1.mga5
+ Revision: 613520
- update to 3.12.17
- drop merged patches:
  * AA01-AA07, AX6, AX20, DG11, DN04, DN10, DU01, DU02, DU10, NR01
  . add patch:
  * NI50: net: ping: refcount issue in ping_init_sock() function (CVE-2014-2851)

* Sun Feb 02 2014 tmb <tmb> 3.12.9-1.mga4
+ Revision: 568606
- update to 3.12.9
- drop perged patches:
  * DA10, DH01, DM10-DM13, FS10-FS12, KF01
- add patches:
  * AA01: e1000e: fix compiler warnings
  * AA02: e752x_edac: Fix pci_dev usage count
  * AA03: drm/nouveau/bios: fix offset calculation for BMPv1 bioses
  * AA04: kvm: x86: fix apic_base enable check
  * AA05: md/raid5: fix long-standing problem with bitmap handling on write failure
  * AA06: mm: hugetlbfs: fix hugetlbfs optimization
  * AA07: mm/mempolicy.c: fix mempolicy printing in numa_maps
  * AX10: x86, x32: Correct invalid use of user timespec in the kernel
    (CVE-2014-0038)

* Sun Jan 19 2014 tmb <tmb> 3.12.8-1.mga4
+ Revision: 566976
- update to 3.12.8
- drop patches:
  * DA20: Marvell 88SE9170 SATA id, merged
- add patches:
  * AX10, AX11: x86 idle: restore mwait_idle()
  * AX15: x86, quirks: Add workaround for AMD F16h Erratum 792
  * AX16: x86, cpu: Add workaround for AMD F16h Erratum 793 (CVE-2013-6885)
  * DA10: revert: 'ACPI: Add BayTrail SoC GPIO and LPSS ACPI IDs' as it
          causes boot hangs
  * DH10: hwmon: (coretemp) Fix truncated name of alarm attributes
  * DM10: md/raid5: Fix possible confusion when multiple write errors occur
  * DM11: md/raid10: fix two bugs in handling of known-bad-blocks
  * DM12: md/raid10: fix bug when raid10 recovery fails to recover a block
  * DM13: md: fix problem when adding device to read-only array with bitmap
  * DN01: ax88179_178a: Remove AX_MEDIUM_ALWAYS_ONE bit in
          AX_MEDIUM_STATUS_MODE register to avoid TX throttling
  * DN05: via-rhine: Fix tx_timeout handling
  * DN10: b43: fix the wrong assignment of status.freq in b43_rx()
  * DU10: revert: 'usbcore: set lpm_capable field for LPM capable root hubs'
          (breaks some usb devices)
  * FS10: vfs: Fix a regression in mounting proc
  * FS11: vfs: In d_path don't call d_dname on a mount point
  * FS12: writeback: Fix data corruption on NFS
  * KF01: fork: Allow CLONE_PARENT after setns(CLONE_NEWPID)
  * NR01: net: rds: fix per-cpu helper usage

* Sun Jan 12 2014 tmb <tmb> 3.12.7-1.mga4
+ Revision: 566396
- update to 3.12.7
- update patches:
  * FR01: reiser4 support
- drop patches:
  * FR02: reiser4 fix, merged in FR01
- add patches:
  * DA01: ACPI: Blacklist Win8 OSI for some HP laptop 2013 models
  * DA02: ACPI: Blacklist Win8 OSI for Asus VivoBook X202E (mga#7857)
  * DA20: ahci: add PCI ID for Marvell 88SE9170 SATA controller
  * DA21: sata_sis: add missing PM support
  * DI01: Input: ALPS - change secondary device's name
  * DI02: Input: ALPS - add support for DualPoint device on Dell XT2
  * DI03: Input: ALPS - add support for "Dolphin" devices
  * DU01: xhci: Avoid infinite loop when sg urb requires too many trbs
  * DU02: xhci: Set scatter-gather limit to avoid failed block writes

* Fri Dec 20 2013 tmb <tmb> 3.12.6-1.mga4
+ Revision: 559221
- update to 3.12.6
- drop merged patches:
  * AX10-AX13: kvm CVE fixes
  * FX02: xfs CVE fix

* Sun Dec 15 2013 tmb <tmb> 3.12.5-1.mga4
+ Revision: 557043
- add patch:
  * FR02: reiser4: add user namespace support
- update to 3.12.5
- add patches:
  * AX10: kvm: rtc_status.dest_map out-of-bounds access (CVE-2013-4587)
  * AX11: kvm: division by zero in apic_get_tmcct() (CVE-2013-6367)
  * AX12: kvm: cross page vapic_addr access (CVE-2013-6368)
  * AX13: kvm: BUG_ON() in apic_cluster_id() (CVE-2013-6376)
  * FX01: xfs: add capability check to free eofblocks ioctl (CVE pending)
  * FX02: xfs: underflow bug in xfs_attrlist_by_handle() (CVE-2013-6382)
- update and enable patches:
  * FR01: Reiser4 support
  * KP01: TuxOnIce support

* Wed Dec 04 2013 tmb <tmb> 3.12.3-1.mga4
+ Revision: 555222
- update to 3.12.3
- drop merged patches:
  * AA01-AA15: stable queue fixes
  * DB10: bluetooth suspend/resume fix
  * MB13-MB15: ndiswrapper buildfixes
- update patches:
  * CK01: -ck patchset including BFS 0.444
- * MB10: ndiswrapper 1.59
- add patches:
  * FS01-FS02: squashfs multi-decompressor support

* Sun Nov 17 2013 tmb <tmb> 3.12.0-2.mga4
+ Revision: 551605
- add -stable queue patches:
  * AA01: net/mlx4_core: Fix call to __mlx4_unregister_mac
  * AA02: net: sctp: do not trigger BUG_ON in sctp_cmd_delete_tcb
  * AA03: net: flow_dissector: fail on evil iph->ihl
  * AA04: virtio-net: correctly handle cpu hotplug notifier during resuming
  * AA05: xen-netback: use jiffies_64 value to calculate credit timeout
  * AA06: cxgb3: Fix length calculation in write_ofld_wr() on 32-bit architectures
  * AA07: tcp: gso: fix truesize tracking
  * AA08: tcp: fix SYNACK RTT estimation in Fast Open
  * AA09: tcp: only take RTT from timestamps if new data is acked
  * AA10: tcp: do not rearm RTO when future data are sacked
  * AA11: ipv6: ip6_dst_check needs to check for expired dst_entries
  * AA12: ipv6: reset dst.expires value when clearing expire flag
  * AA13: hyperv-fb: add pci stub
  * AA14: USB: add new zte 3g-dongle's pid to option.c
  * AA15: ALSA: hda - hdmi: Fix reported channel map on common default layouts
  * DB10: bluetooth: fix suspend/resume issue

* Mon Nov 04 2013 tmb <tmb> 3.12.0-1.mga4
+ Revision: 549321
- update to 3.12 final

* Mon Oct 14 2013 tmb <tmb> 3.12.0-0.rc5.1.mga4
+ Revision: 496719
- update to 3.12-rc5
- drop patches:
  * DN40: bcma BCM43142 support (merged)
- update patches:
  * FO01-FO09: overlayfs support
- rediff patches:
  * NI10: netfilter IFWLOG support
- add patches:
  * MB15: ndiswrapper buildfix for kernel 3.12
- disable patches:
  * CK01: BFS scheduler (needs update to support 3.12)
  * FR01: reiser4 support (needs update to support 3.12)
  * KP01: TuxOnIce support (needs update to support 3.12)
- update filelists
- update defconfigs
- update dkms conflicts

* Thu Oct 03 2013 tmb <tmb> 3.10.15-1.mga4
+ Revision: 491034
- update to 3.10.15
- drop merged patches:
  * DG01, DG02, NM01, NS01, NS02, NW01

* Thu Aug 22 2013 tmb <tmb> 3.10.9-1.mga4
+ Revision: 469190
- update to 3.10.9
- add patches:
  * DG01: drm/radeon: fix WREG32_OR macro setting bits in a register
  * DG02: drm/radeon/r7xx: fix copy paste typo in golden register setup
  * NM01: mac80211: add a flag to indicate CCK support for HT clients
  * NS01: net_sched: psched_ratecfg_precompute() improvements
  * NS02: net_sched: restore "linklayer atm" handling
  * NW01: ath9k: Enable PLL fix only for AR9340/AR9330

* Sat Aug 17 2013 tmb <tmb> 3.10.7-1.mga4
+ Revision: 467214
- update to 3.10.7
- drop merged/obsolete patches:
  * AA01-AA17: stable queue fixes
  * DN01-DN04: alx backport
  * DN22: carl9170 fix
- update patches:
  * CK01: -ck patchset including BFS 0.440
  * FO01-FO09: overlayfs support
  * FR01: Reiser4 support
  * KP01: TuxOnIce support
- add patches:
  * MB14: ndiswrapper kernel 3.10 buildfix
- add support for extended stable builds
- update requires on firmwares and tools
- add conflicts on too old dkms, firmware and
  tools to get better upgrade transactions
- update defconfigs
- update filelists

* Fri Jun 28 2013 tmb <tmb> 3.9.8-1.mga4
+ Revision: 447891
- update to 3.9.8
- add patches:
  * AA01-AA17: -stable queue fixes
  * DN40: bcma: add support for BCM43142 (mga#9378, mga#10611)
- drop merged patches:
  * DN10, DN21, DN30

* Fri Jun 21 2013 tmb <tmb> 3.9.7-1.mga4
+ Revision: 445408
- update to 3.9.7
- drop merged patches:
  * AA01-AA82 (stable queue fixes)
- add patches:
  * DN10: ath9k_htc: Handle IDLE state transition properly
  * DN30: rtl8192cu: Fix problem in connecting to WEP or WPA(1) networks

* Sun Jun 02 2013 tmb <tmb> 3.9.4-1.mga4
+ Revision: 435349
- fix -devel filelist
- update to 3.9.4
- drop merged patches:
  * DI01, DI10-DI12, DI20-DI22, DI30-DI31, DI40-DI41
  *  DI50-DI64, DI70-DI75, DM10, DN10-DN14, DS10
- update patches:
  * CK01: -ck1 patchset including BFS 0.430
  * FR01: Reiser4 support for kernel 3.9
  +  * KP01: TuxOnIce 3.3 for kernel 3.9
- rediff patches:
  * FO01, FO04: overlayfs support
  * MB02: 3rdparty tree merge
- add patches:
  * DN04: fix up alx AR8161 breakage (mga #10079)
  * MB13: ndiswrapper buildfix for kernel 3.9
- update filelists
- update defconfigs

* Sun May 12 2013 tmb <tmb> 3.8.13-1.mga3
+ Revision: 413045
- update to 3.8.13
- drop merged patches:
  * BD01: block discard fix
  * DG01-DG03: drm/radeon fixes
  * DG12: drm/cirrus fix
  * DG21-DG25: drm/i915 fixes
- add patches:
  * DI20-DI22: Input: Cypress PS2 support
  * DI30-DI31: Input: Cypress APA support
  * DI40-DI41: Input: Synaptics bugfixes
  * DI50-DI64: Input: ALPS Rushmore and Dolphin V1 support
  * DI70-DI75: Input: Wacom: DTH-2242 and 0x10d support

* Wed May 08 2013 tmb <tmb> 3.8.12-1.mga3
+ Revision: 412659
- update to 3.8.12
- update patches:
  * DN01-DN03: alx ethernet support including BigFoot e2200
- add patches:
  * DG11: drm/cirrus: Correct register values for 16bpp
  * DG12: drm/cirrus: deal with bo reserve fail in dirty update path
  * DG21: Fix detection of base of stolen memory
  * DG22: Use MLC (l3$) for context objects
  * DG23: Add no-lvds quirk for Fujitsu Esprimo Q900
  * DG24: Fixup Oops in the pipe config computation
  * DG25: set CPT FDI RX polarity bits based on VBT
  * DN21: carl9170: fix frame drop and WARN due to minstrel_ht change
  * DN22: carl9170: remove fast channel change feature (unreliable)
- drop merged patches:
  * AA01: TTY fix
  * DN04: alx fix

* Wed May 01 2013 tmb <tmb> 3.8.11-1.mga3
+ Revision: 411804
- update to 3.8.11
- drop merged patches:
  * AA01-AA03: stable queue fixes
- add patch:
  * DT01: tty: fix up atime/mtime mess, take three (Linus, upstream)

* Sat Apr 27 2013 tmb <tmb> 3.8.10-1.mga3
+ Revision: 411430
- update to 3.8.10
- drop merged / obsolete patches:
  * AA01-AA20: 3.8.6+ stable fixes (merged)
  * DP01: disable-aspm-link check for ath5k (obsolete)
- add patches:
  * AA01: aio: fix possible invalid memory access when DEBUG is enabled
  * AA02: TTY: do not update atime/mtime on read/write (CVE-2013-0160)
  * AA03: TTY: fix atime/mtime regression
  * BD01: block: fix max discard sectors limit
  * DG01: drm/radeon: don't use get_engine_clock() on APUs
    (mga #8077, fdo #62493)
  * DG02: drm/radeon: add some new SI PCI ids
  * DG03: drm/radeon: add new richland pci ids
  * DI10-DI12: intel_idle: add Haswell support
- make EFI_VARS builtin on x86_64
- set DEFAULT_NLS to utf8

* Sun Apr 07 2013 tmb <tmb> 3.8.6-1.mga3
+ Revision: 408975
- update to 3.8.6
- update patches:
  * CK01: -ck patchset inclunding BFS 0.428
  * DN01-DN02: alx ethernet driver
  * F01-F13: overlayfs
  * KP01: TuxOnIce 3.3
  * MB10: ndiswrapper 1.58
- drop merged/obsolete patches:
  * AA01-AA16: stable queue fixes for 3.6 series
  * CK02: BFS boot fix
  * DM50: DVB-S builfix
  * DM60: rttrack buildfix
  * MB13, MB14: ndiswrapper buildfixes
- add patches:
  * AA01-AA20: 3.8 -stable queue fixes
  * DI01: Intel Wellsburg PCH i2c support
  * DM10: Intel Wellsburg PCH lpc support
  * DN03-DN04: alx buildfixes
  * DN10: net: asix: init ASIX AX88772B MAC from EEPROM
  * DN11: net: asix: handle packets crossing URB boundaries
  * DN12: usb/net/asix_devices: Add USBNET HG20F9 ethernet dongle (coling)
  * DN13: asix cleanup
  * DN14: net: ax88179_178a: add ASIX AX88179_178A USB 3.0/2.0 to gigabit
          ethernet adapter support
  * DP01: PCI: Remove not needed check in disable aspm link (fixes ath5k)
  * DS10: Intel Wellsburg PCH alsa support
  * FR01: Reiser4 support
- update defconfigs

* Thu Nov 01 2012 tmb <tmb> 3.6.5-3.mga3
+ Revision: 312036
- add patches:
  * DN01, DN02: alx network driver

* Thu Nov 01 2012 tmb <tmb> 3.6.5-2.mga3
+ Revision: 312001
- add patch:
  * CK02: fix some booting issues with BFS sceduler

* Thu Nov 01 2012 tmb <tmb> 3.6.5-1.mga3
+ Revision: 311881
- update to 3.6.5
- move -doc to Documentation group
- add patches:
  * AA01-AA16: stable queue fixes
  * FE01: ext4: fix unjournaled inode bitmap modification
          (fixes possible data corruption bug)
  * NI14: ipt_IFWLOG buildfix
- update patches:
  * CK01: -ck1 patchset
  * FO01-FO13: overlayfs
  * KP01: TyxOnIce
- disable patches:
  * DA20: acpi shuttle-wmi video blacklist (broken)
- enable ZRAM support
- update filelists
- update defconfigs

* Sat Sep 15 2012 tmb <tmb> 3.5.4-1.mga3
+ Revision: 294091
- update to 3.5.4
- drop merged patches:
  * AA01-AA85, FE01, FU01

* Tue Sep 11 2012 tmb <tmb> 3.5.3-2.mga3
+ Revision: 292370
- add patches:
  * AA01-AA85: stable queue fixes
  * FO01-FO13: overlayfs support (from ubuntu)
  * FE01: ext3: Fix fdatasync() for files with only i_size changes (mga #7343)
  * FU01: udf: Fix data corruption for files in ICB
- drop patches:
  * FU01-FU04: unionfs support (broken)
- update defconfigs

* Mon Aug 27 2012 tmb <tmb> 3.5.3-1.mga3
+ Revision: 284469
- update to 3.5.3

* Thu Aug 16 2012 tmb <tmb> 3.5.2-1.mga3
+ Revision: 281676
- update to 3.5.2
- update patches:
  * CK01: ck1 patchset for 3.5 series kernels including BFS 0.424
  * KP01: TuxOnIce 3.3 for 3.5 series kernels
- drop merged patches:
  * AA01-AA13: (stable queue fixes)
  * BS01: silencing useless scsi ioctl warnings
  * CK02: BFS buildfix
- add patches:
  * FU03, FU04: unionfs buildfixes for 3.5 series kernels
- update filelists
- update defconfigs

* Sat Jul 21 2012 tmb <tmb> 3.4.6-2.mga3
+ Revision: 273184
- make CONFIG_ATA_PIIX, CONFIG_BLK_DEV_SD and CONFIG_CRC_T10DIF
  builtin too, so it actually can boot without initrd
- disable CONFIG_LOGO for less screen flickering during boot

* Fri Jul 20 2012 tmb <tmb> 3.4.6-1.mga3
+ Revision: 272944
- update patch:
  * CK01: -ck3 patchset including BFS v0.424
- add patches:
  * CK02: fix BFS build with sched-nohz-rewrite added in 3.4.6
- update to 3.4.6
- drop patch:
  * DN25: ipw2x00: add support for nl80211 clients (merged)
- add patches:
  * AA01-AA13: stable queue fixes
  * BS01: silence useless scsi ioctl warnings
- make theese config options builtin in order to be able to
  test booting without initrd:
  (see: https://wiki.mageia.org/en/Feature:BootSansRamdisk)
  CONFIG_SCSI_MOD, CONFIG_SCSI, CONFIG_ATA, CONFIG_SATA_AHCI,
  CONFIG_EXT3_FS, CONFIG_EXT4_FS, CONFIG_JBD, CONFIG_JBD2,
  CONFIG_BTRFS_FS, CONFIG_CRYPTO_CRC32C, CONFIG_CRC16,
  CONFIG_LIBCRC32C, CONFIG_ZLIB_DEFLATE

* Wed Jun 27 2012 tmb <tmb> 3.4.4-1.mga3
+ Revision: 264266
- update to 3.4.4
- drop patch:
  * AA01: 3.4.4-rc1 (merged)

* Wed Jun 20 2012 tmb <tmb> 3.4.3-1.mga3
+ Revision: 262367
- update to 3.4.3
- add patch:
  * AA01: 3.4.4-rc1
- drop patch:
  * FE01: ext4 uninit_bg fix (merged)
- update patch:
  * CK01: ck2 patchset including BFS 0.423

* Sat Jun 09 2012 tmb <tmb> 3.4.2-1.mga3
+ Revision: 259019
- update to 3.4.2
- add patch:
  * FE01: ext4: fix the free blocks calculation for ext3
          file systems w/ uninit_bg
- require kmod instead of module-init-tools

* Mon Jun 04 2012 tmb <tmb> 3.4.1-1.mga3
+ Revision: 254438
- disable ZRAM in staging for now
- update to 3.4.1
- drop merged patches:
  * DA60, DA61: ahci/ata ids
  * DG01-DG04, DG20-DG21, DG40-DG44, DG60: drm backports
  * DN10-DN11: ath5k stablilty fixes
  * DS20-DS24: sound fixes
- update patches:
  * CK01: ck1 patchset including BFS 0.422
  * FU01: unionfs 2.5.11
  * KP01: tuxonice 3.2.1
  * NI10-NI11: netfilter IFWLOG support
  * NI16: netfilter psd support
- add patches:
  * DM60: radio-rttrack buildfix
  * FU02: unionfs buildfix for kernel-3.4
- drop patches:
  * DA50: prefer ata over ide hack, needs to be fixed properly
  * DN20: disabling powersave on rt2800usb
  * LK01: lib/Kconfig.debug text update
- update defconfigs
- update filelists

* Thu May 17 2012 tmb <tmb> 3.3.6-2.mga2
+ Revision: 235847
- revert switching server kernels to SLAB allocator at it fails to boot
  with BFS scheduler (reported/confirmed by Charles A Edwards.on -dev ml)
- add patches:
  * DN25: ipw2x00: add support for nl80211 clients like Network Manager (#5720)
  * DS20: ALSA: echoaudio: Remove incorrect part of assertion
  * DS21: ALSA: HDA: Lessen CPU usage when waiting for chip to respond
  * DS22: ALSA: hda/realtek - Add missing CD-input pin for MSI-7350 mobo
  * DS23: ALSA: hda/idt - Fix power-map for speaker-pins with some HP laptops

* Sat May 12 2012 tmb <tmb> 3.3.6-1.mga2
+ Revision: 235519
- update to 3.3.6
- drop merged patches:
  * AA01-AA32: stable queue fixes
  * DP10-DP13: samsung-laptop dmitable addons
- switch server kernels back to SLAB allocator as it performs better
  on bigger server hardware and workloads

* Fri May 11 2012 tmb <tmb> 3.3.5-1.mga2
+ Revision: 235253
- update to 3.3.5
- drop merged patches:
  * DN15-DN17: iwlwifi fixes
- add patches from stable queue
  * AA01-AA32: fixes all over

* Sat Apr 28 2012 tmb <tmb> 3.3.4-1.mga2
+ Revision: 234040
- update to 3.3.4
- require dracut >= 017-9
- add patches:
  * DN16: iwlwifi: use 6000G2B for 6030 device series
  * DN17: iwlwifi: fix hardware queue programming

* Mon Apr 23 2012 tmb <tmb> 3.3.3-1.mga2
+ Revision: 232881
- update patch:
  * KP01: TuxOnIce 3.2.1 for kernel-3.3
- update to 3.3.3
- add patches:
  * BF01: floppy: disable pnp autoloading
  * DN10: ath5k: do not stop queues for full calibration
  * DN11: ath5k: do not re-run AGC calibration periodically
  * DN15: iwlwifi: use correct released ucode version

* Tue Apr 03 2012 tmb <tmb> 3.3.1-1.mga2
+ Revision: 228106
- update to 3.3.1
- drop merged patches:
  * DM51, SR01-SR03
- update patch:
  * CK01: -ck1 patchset including BFS v0.420
- add patches:
  * DA50: ata: prefer ata drivers over ide drivers when both are built (Anssi)
  * DA60-DA61: ata: add ide/ahci/raid mode support for Intel Lynx Point chipset
  * DG01-DG04: drm: add upstream drm changes to support gpu driver backports
  * DG20, DG21: drm/radeon: backport support for Southern Islands (HD7xxx)
  		GPUs and Trinity APUs
  * DG40-DG44: drm/nouveau: backport Kepler (GTX6xx) support
  * DG60: drm/i915: add Ivy Bridge GT2 Server entries
- update defconfigs

* Mon Mar 19 2012 tmb <tmb> 3.3.0-1.mga2
+ Revision: 224401
- update to 3.3 final
- add patches:
    * DM50: media: fix initialization on Hauppauge WinTV Nova HD-S2
            and similar hardware
    * DM51: media/tda10071: correct delivery system to DVB-S/S2
- update defconfigs

* Sun Mar 11 2012 tmb <tmb> 3.3.0-0.rc7.1.mga2
+ Revision: 222618
- update to 3.3-rc7

* Wed Mar 07 2012 tmb <tmb> 3.3.0-0.rc6.1.mga2
+ Revision: 220928
- update to 3.3-rc6
- update patches:
    * FU01: unionfs 2.5.11
    * MB10, MB13, MB14: ndiswrapper 1.57
- rediff patches:
    * NI15, NI16: netfilter psd support
    * patch disabling mrproper in -devel rpms
- disable patch:
    * CK01: -ck1 patchset including BFS sceduler (needs update to 3.3 series)
- update defconfigs
- update filelists

* Thu Mar 01 2012 tmb <tmb> 3.2.9-1.mga2
+ Revision: 216493
- update to 3.2.9
- require dracut >= 017-1
- drop merged patches:
    * DG01, DP01, DU01, NM01
- add patches:
    * SR01-SR03: fix nonworking r8172u wireless driver in staging (#4491)

* Sun Feb 26 2012 tmb <tmb> 3.2.7-1.mga2
+ Revision: 214975
- update to 3.2.7
- drop merged patches AA01-AA28
- add patches:
    * DG01: drm/radeon/kms: fix MSI re-arm on rv370+
    * DP01: PCI: workaround hard-wired bus number
    * DS20, DS21: fix nonworking r8172u wireless driver in staging (#4491)
    * DU01: xhci: Fix oops caused by more USB2 ports than USB3 ports
    * NM01: mac80211: Fix a rwlock bad magic bug

* Thu Feb 16 2012 tmb <tmb> 3.2.6-1.mga2
+ Revision: 209856
- update to 3.2.6
- add current stable queue (28 fixes, AA01-AA28)
- require dracut >= 016-1 for xz compressed modules support and
  other needed fixes
- compress modules with xz

* Tue Feb 07 2012 tmb <tmb> 3.2.5-1.mga2
+ Revision: 206041
- update to 3.2.5
- drop merged patch
    * DP01: ASPM rework

* Thu Jan 26 2012 tmb <tmb> 3.2.2-1.mga2
+ Revision: 201866
- correct requires: module-init-tools >= 3.16-14 for xz support
- require module-init-tools >= 3.6-14 for xz support
- require dracut instead of mkinitrd
- update to 3.2.2 (CVE-2012-0056)
- update patches:
    * CK01: Con Kolivas 3.2-ck1 patchset
    * KP01: TuxOnIce 3.2.1

* Sun Jan 15 2012 tmb <tmb> 3.2.1-1.mga2
+ Revision: 196339
- update to 3.2.1

* Thu Jan 05 2012 tmb <tmb> 3.2.0-1.mga2
+ Revision: 191904
- update to 3.2
- add patches:
    * FU02: fix unionfs build with 3.2 series kernels
    * MB13: fix ndiswrapper build with 3.2 series kernels
- update patches:
    * CK01: BFS scheduler 0.416
- rediff patches:
    * DP11, MB02, NI11, NI16, Source2
- drop patches:
    * FB01: btrfs fix, merged
- update filelists and defconfigs
- make sure -devel rpm is installed before triggering dkms rebuild

* Thu Dec 22 2011 tmb <tmb> 3.1.6-1.mga2
+ Revision: 185705
- update to 3.1.6
- drop patch DS01 (merged)
- trigger dkms build in posttrans so modules get built at kernel install
  instead of at boot (speeds up boot time with new kernel)
- update desktop(586) & laptop summaries and descriptions to point out that
  only 3-3.5GB RAM is detected on 32bit, and that server kernel is needed to
  fully support 4GB or more
- switch transparent hugepages from on by default to madvise (only enabled
  for apps that requests it), as it fixes desktop freeze when accessing
  slow media such as usb (thanks to fbui/mdv mail on @cooker ml).

* Fri Dec 09 2011 tmb <tmb> 3.1.5-1.mga2
+ Revision: 179824
- update to 3.1.5
- drop merged patches:
    * DG01-DG06, FX01-FX06
- add patch:
    * DS01: ALSA: hda/realtek - Fix Oops in alc_mux_select()
- clean spec: drop buildroot and defattr

* Tue Dec 06 2011 tmb <tmb> 3.1.4-3.mga2
+ Revision: 177141
- fix patch NI12: IFWLOG: fix return value of checkentry
  (not properly modified in 2.6.35+ patch, blino, #3594)
- rebuild with GCC-4.6.2

* Wed Nov 30 2011 tmb <tmb> 3.1.4-2.mga2
+ Revision: 174468
- update patch:
  * CK01: upstream 3.1.0-ck2 including BFS 0.415

* Tue Nov 29 2011 tmb <tmb> 3.1.4-1.mga2
+ Revision: 174083
- update to 3.1.4
  * reverts usb patch that broke isochronous devices
    (i.e. webcam, audio, or other streaming devices)

* Mon Nov 28 2011 tmb <tmb> 3.1.3-1.mga2
+ Revision: 173233
- update to 3.1.3
- add patches:
  * DG01: i915: Fix inconsistent backlight level during disabled
  * DG02: drm: fix integer overflow in drm_mode_dirtyfb_ioctl()
  * DG03: radeon/kms: fix up gpio i2c mask bits for r4xx for real
  * DG04: i915: Ivybridge still has fences
  * DG05: i915: Turn on a required 3D clock gating bit on Sandybridge
  * DG06: i915: Turn on another required clock gating bit on Sandybridge
  * DP01: pci: rework ASPM disable code (brings power usage back down
               to 2.6.37 level)
  * FX01: don't serialise direct IO reads on page cache checks
          (fixes performance regression introduced in 2.6.38)
  * FX02: avoid direct I/O write vs buffered I/O race
  * FX03: return -EIO when xfs_vn_getattr() failed
  * FX04: fix buffer flushing during unmount
  * FX05: fix possible memory corruption in xfs_readlink
  * FX06: use doalloc flag in xfs_qm_dqattach_one()
- update patches:
  * FU01: unionfs 2.5.10 for 3.1.3
  * MB02: merge 3rdparty support
  * MB10-MB12: ndiswrapper 1.57-rc1
- drop patches:
  * DS15: its replaced by SND_HDA_PREALLOC_SIZE config option
  * MB13-MB17: ndiswrapper fixes, merged
- disable patches:
  * KP01: TuxOnIce support, currently broken
- dont ship openrisc arch files
- update defconfigs

* Tue Oct 25 2011 tmb <tmb> 3.0.8-1.mga2
+ Revision: 158005
- update to 3.0.8
  * drop merged patch: DM20
- enable PM_RUNTIME and USB_SUSPEND (mga #3139)

* Tue Oct 18 2011 tmb <tmb> 3.0.7-1.mga2
+ Revision: 156418
- update to 3.0.7
- update patch CK01: 3.0.7-ck1 including BFS 0.413
- re-enable usblp as it is needed by both usb-pp adapters and some printers
  (mga #2240, #2264) (cups is patched to work with both usblp and libusb)

* Mon Oct 03 2011 tmb <tmb> 3.0.6-1.mga2
+ Revision: 151411
- update to 3.0.6
- add patch:
    * DM20: fix boot hang on uvc webcam init (mga #2425)

* Tue Aug 30 2011 tmb <tmb> 3.0.4-1.mga2
+ Revision: 136495
- update to 3.0.4
- drop merged patch: AA01
- update to 3.0.3
- update patches:
    * CK01: Con Kolivas -ck patchset including BFS
    * FU01: unionfs 2.5.9.2
    * KP01: TuxonIce 3.2
- drop merged patches:
    * CK02, DA60-DA61, DG10-DG14, DN08, DN15-DN19, DP05-DP08
    * DP20-DP26, DP30, DV11, FU02-FU03, MK01, NI30-NI31
- add patches:
    * AA01: genirq: Fix wrong bit operation
    * DP10-DP12: samsung-laptop: support nc110, nc210, r700, x520
    * DP13: samsung-laptop: fix support for older N150, N210, N220
    * FB01: btrfs: btrfs_calc_avail_data_space: cope with no read_write devices
    * MB17: ndiswrapper buildfix for 3.0
    * MC84: viahss buildfix for 3.0
- rediff patches:
    * NI16: netfilter psd mdv/mga modifications
- disable patches:
    * DV01-DV02: framebuffer oops fixes (should not be needed anymore)
    * FR01: reiser4 support (broken)
- adapt spec for 3.0 series version changes
- change kernel-tmb-source to noarch
- build with -s(ilent) to only log varnings and errors
- update defconfigs

* Sun Jun 19 2011 tmb <tmb> 2.6.38.8-1.mga2
+ Revision: 110087
- update to 2.6.38.8 (CVE-2011-1017)
- drop merged patches:
    * AA01, DP15
- add patches:
    * CK02: update bfs scheduler to 0.406
    * MK01: ksm: fix race between ksmd and exiting task (CVE-2011-2183)
- add mgaver to 'uname -r'

* Sun May 22 2011 tmb <tmb> 2.6.38.7-1.mga1
+ Revision: 100142
- update to 2.6.38.7 (CVE-2011-1770, CVE-2011-1776, CVE-2011-1927)
- drop merged patches:
    * DG20-DG24
- update patches:
    * FU01, FU03: rollback unionfs to a working 2.5.8
- add patches:
    * AA01: block: rescan partitions on invalidated devices on -ENOMEDIA too
    * DN17: r8169: add a new chip for RTL8105
    * DN18: r8169: add a new chip for RTL8168DP
    * DN19: r8169: add support for RTL8168E/RTL8111E

* Thu May 12 2011 tmb <tmb> 2.6.38.6-1.mga1
+ Revision: 97433
- update to 2.6.38.6
- drop merged patches:
    * AX01
- add patches:
    * DG20: drm/radeon/kms: add pci id to acer travelmate quirk for 5730
    * DG21: drm/radeon/kms: fix gart setup on fusion parts (v2) backport
    * DG22: drm/i915/dp: Be paranoid in case we disable a DP before it is attached
    * DG23: drm/i915/lvds: Only act on lid notify when the device is on
    * DG24: drm/i915: Release object along create user fb error path
    * DP30: revert: "dell-laptop: Toggle the unsupported hardware killswitch"
            as it causes regressions on existing hw (reported by Colin Guthrie)
    * SM02: add support for compressing modules with xz
- clean /lib/modules tree on uninstall
- disable ACPI_PROCFS_POWER as its obsoleted by the sysfs interface
- drop hardcoded vendor references from summarys and descriptions (#1161)
- drop warnings about being experimental kernel

* Wed May 04 2011 tmb <tmb> 2.6.38.5-1.mga1
+ Revision: 94546
- update to 2.6.38.5
- add patches:
    * AX01: x86, AMD: K8 Rev.A-E processors are subject to erratum 400
    * AX05: x86, 32bit: raise default vmalloc area to 192MB (Anssi, #904)
    * DN15: r8169: add support for RTL8105E
    * DN16: r8169: be verbose when unable to load firmware
    * DN20: disable powersaving on rt2800 as it is broken (noted by rtp)
    * DP06-DP08: samsung-laptop: add support for N230, R410P
    * DP20-DP26: hp-wmi: add support for rfkill on HP Mini 5102 (Anssi)
- update patches:
    * FU01: unionfs 2.5.9
- drop patches:
    * FU03: unionfs oops fix (obsolete)
- enable DEBUG_RODATA and DEBUG_SET_MODULE_RONX (tv)

* Sun Apr 24 2011 tmb <tmb> 2.6.38.4-1.mga1
+ Revision: 90161
- update to 2.6.38.4
- update patches:
    * DG10: drm/i915: Fix tiling corruption from pipelined fencing
    * NI30, NI31: ipset 6.4
- add patches:
    * DA60, DA61: ide/ahci/raid support for Intel Panther Point
    * DF01: add old ieee1394 aliases to new firewire stack
    * DG11: drm: Retry i2c transfer of EDID block after failure
    * DG12: drm/i915/dp: Sanity check eDP existence
    * DG13: drm/i915: Restore missing command flush before interrupt on BLT ring
    * DG14: drm/i915: Avoid unmapping pages from a NULL address space
    * DG15: drm/i915: Enable GPU semaphores by default
    * DM01: add dm-raid45 aliases to the new dm-raid target
    * DP15: intel_ips: fix monitor thread to use TASK_INTERRUPTIBLE

* Sat Apr 16 2011 tmb <tmb> 2.6.38.3-1.mga1
+ Revision: 86256
- update to 2.6.38.3
- drop merged patches

* Tue Apr 12 2011 tmb <tmb> 2.6.38.2-2.mga1
+ Revision: 83510
- add -stable queue patches (31 fixes)
- update patches:
    * CK01: Con Kolivas -ck3 patchset including bfs 0.400
    * FR01: reiser4 for 2.6.38 final
- drop patches:
    * FR02: reiser4 buildfix (merged)

* Tue Mar 29 2011 tmb <tmb> 2.6.38.2-1.mga1
+ Revision: 78709
- update to 2.6.38.2
- drop merged patches:
    * AX01, AX10, FS01-FS03, LD01-LD02 (xz support)
    * CK02 (-ck1 patchset buildfix)
    * DA01-DA03 (ahci ids)
    * DG01-DG02 (gpu fixes)
    * DM10-DM14 (dm-raid45, replaced by new dm-raid target)
    * DM20 (dm-crypt multicore support)
    * DP06 (samsung-laptop buildfix)
    * KB01 (headers_install_all export fix)
    * SE01 (staging fix)
- rediff patches:
    * AI01 (Toshiba Equium A60 fix)
    * DV01-DV02 (framebuffer oops and deadlock fixes)
    * MB02 (3rdparty merge)
- update patches:
    * CK01: Con Kolivas -ck1 patchset including BFS v363
    * DP05: update samsung-laptop to the one being merged in
            2.6.39 (replaces old samsung-backlight)
    * FR01-FR02: reiser4 support
    * FU01-FU03: unionfs 2.5.8
    * KP01: TuxOnIce
    * S2: disable mrproper on -devel rpms
- add patches:
    * DA20: acpi video blacklist (needed for shuttle-wmi)
    * DG10: drm/i915: Fix pipelined fencing
    * DP10: shuttle-wmi support
    * MB16: ndiswrapper buildfix
- update defconfigs and filelists

* Mon Mar 21 2011 tmb <tmb> 2.6.37.4-1.mga1
+ Revision: 75092
- update to 2.6.37.4 (CVE-2011-1013, CVE-2011-1019, CVE-2011-1076)
- drop merged patch:
    * NI01
- add patches:
    * AX10: x86, quirk: Fix SB600 revision check
    * DA01: ahci: AHCI mode SATA patch for Intel DH89xxCC DeviceIDs
    * DA02: ahci: AHCI mode SATA patch for Intel Patsburg SATA RAID controller
    * DA03: ahci: recognize Marvell 88se9125 PCIe SATA 6.0 Gb/s controller
    * DG01: drm: Hold the mode mutex whilst probing for sysfs status
    * DG02: drm/i915: Fix calculation of backlight value in combined mode
- drop S5, not needed anymore as we ship unprepared kernel-source

* Sun Feb 27 2011 tmb <tmb> 2.6.37.2-1.mga1
+ Revision: 61100
- imported package kernel-tmb

